@@ -37,6 +37,7 @@ const std::map <llvm::StringRef, hipCounter> CUDA_INCLUDE_MAP {
   {"vector_types.h",                                        {"hip/hip_vector_types.h",                                "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"cuda_profiler_api.h",                                   {"hip/hip_runtime_api.h",                                 "", CONV_INCLUDE,                API_RUNTIME, 0}},
   {"cooperative_groups.h",                                  {"hip/hip_cooperative_groups.h",                          "", CONV_INCLUDE,                API_RUNTIME, 0}},
+  {"library_types.h",                                       {"hip/library_types.h",                                   "", CONV_INCLUDE,                API_RUNTIME, 0}},
   // cuComplex includes
   {"cuComplex.h",                                           {"hip/hip_complex.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_COMPLEX, 0}},
   // cuBLAS includes
@@ -44,31 +45,38 @@ const std::map <llvm::StringRef, hipCounter> CUDA_INCLUDE_MAP {
   {"cublas_v2.h",                                           {"hipblas.h",                                    "rocblas.h", CONV_INCLUDE_CUDA_MAIN_V2_H, API_BLAS, 0}},
   {"cublas_api.h",                                          {"hipblas.h",                                    "rocblas.h", CONV_INCLUDE,                API_BLAS, 0}},
   // cuRAND includes
-  {"curand.h",                                              {"hiprand.h",                                             "", CONV_INCLUDE_CUDA_MAIN_H,    API_RAND, 0}},
-  {"curand_kernel.h",                                       {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_discrete.h",                                     {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_discrete2.h",                                    {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_globals.h",                                      {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_lognormal.h",                                    {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mrg32k3a.h",                                     {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32.h",                                       {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32_host.h",                                  {"hiprand_mtgp32_host.h",                                 "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_mtgp32_kernel.h",                                {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand.h",                                              {"hiprand/hiprand.h",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_RAND, 0}},
+  {"curand_kernel.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_discrete.h",                                     {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_discrete2.h",                                    {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_globals.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_lognormal.h",                                    {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mrg32k3a.h",                                     {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32_host.h",                                  {"hiprand/hiprand_mtgp32_host.h",                         "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_mtgp32_kernel.h",                                {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
   {"curand_mtgp32dc_p_11213.h",                             {"rocrand_mtgp32_11213.h",                                "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_normal.h",                                       {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_normal_static.h",                                {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_philox4x32_x.h",                                 {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_poisson.h",                                      {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_precalc.h",                                      {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
-  {"curand_uniform.h",                                      {"hiprand_kernel.h",                                      "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_normal.h",                                       {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_normal_static.h",                                {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_philox4x32_x.h",                                 {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_poisson.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_precalc.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
+  {"curand_uniform.h",                                      {"hiprand/hiprand_kernel.h",                              "", CONV_INCLUDE,                API_RAND, 0}},
   // cuDNN includes
   {"cudnn.h",                                               {"hipDNN.h",                               "miopen/miopen.h", CONV_INCLUDE_CUDA_MAIN_H,    API_DNN, 0}},
   // cuFFT includes
-  {"cufft.h",                                               {"hipfft.h",                                              "", CONV_INCLUDE_CUDA_MAIN_H,    API_FFT, 0}},
-  {"cufftXt.h",                                             {"hipfftXt.h",                                            "", CONV_INCLUDE,                API_FFT, 0}},
+  {"cufft.h",                                               {"hipfft/hipfft.h",                                       "", CONV_INCLUDE_CUDA_MAIN_H,    API_FFT, 0}},
+  {"cufftXt.h",                                             {"hipfft/hipfftXt.h",                                     "", CONV_INCLUDE,                API_FFT, 0}},
   // cuSPARSE includes
   {"cusparse.h",                                            {"hipsparse.h",                                "rocsparse.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SPARSE, 0}},
   {"cusparse_v2.h",                                         {"hipsparse.h",                                "rocsparse.h", CONV_INCLUDE_CUDA_MAIN_V2_H, API_SPARSE, 0}},
+  // cuSOLVER includes
+  {"cusolverDn.h",                                          {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
+  {"cusolverMg.h",                                          {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
+  {"cusolverRf.h",                                          {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
+  {"cusolverSp.h",                                          {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
+  {"cusolverSp_LOWLEVEL_PREVIEW.h",                         {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
+  {"cusolver_common.h",                                     {"hipsolver.h",                      "rocsolver/rocsolver.h", CONV_INCLUDE_CUDA_MAIN_H,    API_SOLVER, 0}},
   // CUB includes
   {"cub/cub.cuh",                                           {"hipcub/hipcub.hpp",                                     "", CONV_INCLUDE_CUDA_MAIN_H,    API_CUB, 0}},
   // CAFFE2 includes
@@ -114,6 +122,8 @@ const std::map<llvm::StringRef, hipCounter> &CUDA_RENAMES_MAP() {
   ret.insert(CUDA_RTC_TYPE_NAME_MAP.begin(), CUDA_RTC_TYPE_NAME_MAP.end());
   ret.insert(CUDA_RTC_FUNCTION_MAP.begin(), CUDA_RTC_FUNCTION_MAP.end());
   ret.insert(CUDA_DEVICE_TYPE_NAME_MAP.begin(), CUDA_DEVICE_TYPE_NAME_MAP.end());
+  ret.insert(CUDA_SOLVER_TYPE_NAME_MAP.begin(), CUDA_SOLVER_TYPE_NAME_MAP.end());
+  ret.insert(CUDA_SOLVER_FUNCTION_MAP.begin(), CUDA_SOLVER_FUNCTION_MAP.end());
   return ret;
 };
 
@@ -146,6 +156,8 @@ const std::map<llvm::StringRef, cudaAPIversions> &CUDA_VERSIONS_MAP() {
   ret.insert(CUDA_CUB_FUNCTION_VER_MAP.begin(), CUDA_CUB_FUNCTION_VER_MAP.end());
   ret.insert(CUDA_RTC_TYPE_NAME_VER_MAP.begin(), CUDA_RTC_TYPE_NAME_VER_MAP.end());
   ret.insert(CUDA_RTC_FUNCTION_VER_MAP.begin(), CUDA_RTC_FUNCTION_VER_MAP.end());
+  ret.insert(CUDA_SOLVER_TYPE_NAME_VER_MAP.begin(), CUDA_SOLVER_TYPE_NAME_VER_MAP.end());
+  ret.insert(CUDA_SOLVER_FUNCTION_VER_MAP.begin(), CUDA_SOLVER_FUNCTION_VER_MAP.end());
   return ret;
 }
 
@@ -178,5 +190,7 @@ const std::map<llvm::StringRef, hipAPIversions> &HIP_VERSIONS_MAP() {
   ret.insert(HIP_CUB_FUNCTION_VER_MAP.begin(), HIP_CUB_FUNCTION_VER_MAP.end());
   ret.insert(HIP_RTC_TYPE_NAME_VER_MAP.begin(), HIP_RTC_TYPE_NAME_VER_MAP.end());
   ret.insert(HIP_RTC_FUNCTION_VER_MAP.begin(), HIP_RTC_FUNCTION_VER_MAP.end());
+  ret.insert(HIP_SOLVER_TYPE_NAME_VER_MAP.begin(), HIP_SOLVER_TYPE_NAME_VER_MAP.end());
+  ret.insert(HIP_SOLVER_FUNCTION_VER_MAP.begin(), HIP_SOLVER_FUNCTION_VER_MAP.end());
   return ret;
 }
