@@ -39,6 +39,8 @@ namespace doc {
   typedef functionMap typeMap;
   typedef map<StringRef, cudaAPIversions> versionMap;
   typedef map<StringRef, hipAPIversions> hipVersionMap;
+  typedef map<llvm::StringRef, hipAPIChangedVersions> hipChangedVersionMap;
+  typedef map<llvm::StringRef, cudaAPIChangedVersions> cudaChangedVersionMap;
 
   const string sEmpty = "";
   const string sMd = "md";
@@ -72,6 +74,16 @@ namespace doc {
   const string sROCBLAS_csv = sROCBLAS + csv_ext;
   const string sCUBLAS = "CUBLAS";
 
+  const string sSOLVER = "CUSOLVER_API_supported_by_HIP";
+  const string sSOLVER_md = sSOLVER + md_ext;
+  const string sSOLVER_csv = sSOLVER + csv_ext;
+  const string sSOLVER_and_ROC_md = sSOLVER + sandROC + md_ext;
+  const string sSOLVER_and_ROC_csv = sSOLVER + sandROC + csv_ext;
+  const string sROCSOLVER = "CUSOLVER_API_supported_by_ROC";
+  const string sROCSOLVER_md = sROCSOLVER + md_ext;
+  const string sROCSOLVER_csv = sROCSOLVER + csv_ext;
+  const string sCUSOLVER = "CUSOLVER";
+
   const string sRAND = "CURAND_API_supported_by_HIP";
   const string sRAND_md = sRAND + md_ext;
   const string sRAND_csv = sRAND + csv_ext;
@@ -127,8 +139,11 @@ namespace doc {
   const string sHIPandMIOPEN = "HIP and MIOPEN";
   const string sA = "A";
   const string sD = "D";
+  const string sC = "C";
   const string sR = "R";
   const string sE = "E";
+  const hipChangedVersionMap hipChangedVersionMapEmpty = {};
+  const cudaChangedVersionMap cudaChangedVersionMapEmpty = {};
 
   enum docType {
     none = 0,
@@ -171,6 +186,8 @@ namespace doc {
       virtual const typeMap &getTypes() const = 0;
       virtual const versionMap &getFunctionVersions() const = 0;
       virtual const hipVersionMap &getHipFunctionVersions() const = 0;
+      virtual const hipChangedVersionMap &getHipChangedFunctionVersions() const { return hipChangedVersionMapEmpty; };
+      virtual const cudaChangedVersionMap &getCudaChangedFunctionVersions() const { return cudaChangedVersionMapEmpty; };
       virtual const versionMap &getTypeVersions() const = 0;
       virtual const hipVersionMap &getHipTypeVersions() const = 0;
       virtual const string &getAPI() const { return sHIP; }
@@ -228,6 +245,8 @@ namespace doc {
             const functionMap &ftMap = isTypeSection(s.first, getSections()) ? getTypes() : getFunctions();
             const versionMap &vMap = isTypeSection(s.first, getSections()) ? getTypeVersions() : getFunctionVersions();
             const hipVersionMap &hMap = commonHipVersionMap.empty() ? (isTypeSection(s.first, getSections()) ? getHipTypeVersions() : getHipFunctionVersions()) : commonHipVersionMap;
+            const hipChangedVersionMap &hChangedMap = getHipChangedFunctionVersions();
+            const cudaChangedVersionMap &cudaChangedMap = getCudaChangedFunctionVersions();
             functionMap fMap;
             for (auto &f : ftMap) {
               if (f.second.apiSection == s.first) {
@@ -246,7 +265,7 @@ namespace doc {
             string sS = (doc == md) ? "|" : ",";
             stringstream rows;
             for (auto &f : fMap) {
-              string a, d, r, ha, hd, hr, he, ra, rd, rr, re;
+              string a, d, c, r, ha, hd, hc, hr, he, ra, rd, rc, rr, re, cc;
               for (auto &v : vMap) {
                 if (v.first == f.first) {
                   a = Statistics::getCudaVersion(v.second.appeared);
@@ -255,6 +274,16 @@ namespace doc {
                   break;
                 }
               }
+              auto cudacv = cudaChangedMap.find(f.first);
+              if (cudacv != cudaChangedMap.end()) {
+                int icount = 0;
+                for (auto &cv : cudacv->second) {
+                  if (icount > 0)
+                    c += ", ";
+                  c += Statistics::getCudaVersion(cv);
+                  icount++;
+                }
+              }
               auto hv = (isROC) ? hMap.find(f.second.rocName) : hMap.find(f.second.hipName);
               if (hv != hMap.end() && ((!Statistics::isRocUnsupported(f.second) && isROC) || (!Statistics::isHipUnsupported(f.second) && !isROC))) {
                 ha = Statistics::getHipVersion(hv->second.appeared);
@@ -262,6 +291,20 @@ namespace doc {
                 hr = Statistics::getHipVersion(hv->second.removed);
                 he = Statistics::getHipVersion(hv->second.experimental);
               }
+              auto hcv = (isROC) ? hChangedMap.find(f.second.rocName) : hChangedMap.find(f.second.hipName);
+              if (hcv != hChangedMap.end() && ((!Statistics::isRocUnsupported(f.second) && isROC) || (!Statistics::isHipUnsupported(f.second) && !isROC))) {
+                int icount = 0;
+                for (auto &cv : hcv->second) {
+                  if (icount > 0)
+                    cc += ", ";
+                  cc += Statistics::getHipVersion(cv);
+                  icount++;
+                }
+                if (isROC)
+                  rc = cc;
+                else
+                  hc = cc;
+              }
               if (isJoint()) {
                 auto rv = hMap.find(f.second.rocName);
                 if (rv != hMap.end() && !Statistics::isRocUnsupported(f.second)) {
@@ -270,6 +313,16 @@ namespace doc {
                   rr = Statistics::getHipVersion(rv->second.removed);
                   re = Statistics::getHipVersion(rv->second.experimental);
                 }
+                auto hrv = hChangedMap.find(f.second.rocName);
+                if (hrv != hChangedMap.end() && !Statistics::isRocUnsupported(f.second)) {
+                  int icount = 0;
+                  for (auto &cv : hrv->second) {
+                    if (icount > 0)
+                      rc += ", ";
+                    rc += Statistics::getHipVersion(cv);
+                    icount++;
+                  }
+                }
               }
               string sHip, sRoc;
               if (isROC)
@@ -297,9 +350,9 @@ namespace doc {
                       break;
                     case full:
                     default:
-                      rows << a << sS << d << sS << r << sS << sHip << sS << ha << sS << hd << sS << hr << sS << he;
+                      rows << a << sS << d << sS << c << sS << r << sS << sHip << sS << ha << sS << hd << sS << (isROC ? rc : hc) << sS << hr << sS << he;
                       if (isJoint())
-                        rows << sS << sRoc << sS << ra << sS << rd << sS << rr << sS << re;
+                        rows << sS << sRoc << sS << ra << sS << rd << sS << rc << sS << rr << sS << re;
                       rows << endl;
                       break;
                   }
@@ -316,10 +369,10 @@ namespace doc {
                       break;
                     case full:
                     default:
-                      rows << (a.empty() ? " " : a) << sS << (d.empty() ? " " : d) << sS << (r.empty() ? " " : r) << sS << sHip << sS <<
-                        (ha.empty() ? " " : ha) << sS << (hd.empty() ? " " : hd) << sS << (hr.empty() ? " " : hr) << sS << (he.empty() ? " " : he) << sS;
+                      rows << (a.empty() ? " " : a) << sS << (d.empty() ? " " : d) << sS << (c.empty() ? " " : c) << sS << (r.empty() ? " " : r) << sS << sHip << sS <<
+                        (ha.empty() ? " " : ha) << sS << (hd.empty() ? " " : hd) << sS << (isROC ? (rc.empty() ? " " : rc) : (hc.empty() ? " " : hc)) << sS << (hr.empty() ? " " : hr) << sS << (he.empty() ? " " : he) << sS;
                       if (isJoint())
-                        rows << sRoc << sS << (ra.empty() ? " " : ra) << sS << (rd.empty() ? " " : rd) << sS << (rr.empty() ? " " : rr) << sS << (re.empty() ? " " : re) << sS;
+                        rows << sRoc << sS << (ra.empty() ? " " : ra) << sS << (rd.empty() ? " " : rd) << sS << (rc.empty() ? " " : rc) << sS << (rr.empty() ? " " : rr) << sS << (re.empty() ? " " : re) << sS;
                       rows << endl;
                       break;
                   }
@@ -330,16 +383,16 @@ namespace doc {
             stringstream section, section_header;
             section_header << (doc == md ? "## **" : "") << (format != compact ? s.first : compact_only_cur_sec_num) << ". " << string(s.second) << (doc == md ? "**" : "") << endl << endl;
             section << (doc == md ? "|**" : "") << sCUDA << sS << (format == full ? sA : "") << (format == full ? sS : "") <<
-              sD << sS << (format == full ? sR : "") << (format == full ? sS : "") << getAPI() << sS << (format == full ? sA : "") << (format == full ? sS : "") <<
-              sD << (format == full ? sS : "") << (format == full ? sR : "") << sS << sE;
+              sD << sS << (format == full ? sC : "") << (format == full ? sS : "") << (format == full ? sR : "") << (format == full ? sS : "") << getAPI() << sS << (format == full ? sA : "") << (format == full ? sS : "") <<
+              sD << (format == full ? sS : "") << (format == full ? sC : "") << (format == full ? sS : "") << (format == full ? sR : "") << sS << sE;
             if (isJoint())
-              section << sS << getSecondAPI() << sS << (format == full ? sA : "") << (format == full ? sS : "") << sD << (format == full ? sS : "") << (format == full ? sR : "") << sS << sE;
+              section << sS << getSecondAPI() << sS << (format == full ? sA : "") << (format == full ? sS : "") << sD << (format == full ? sS : "") << (format == full ? sC : "") << (format == full ? sS : "") << (format == full ? sR : "") << sS << sE;
             section << (doc == md ? "**|" : "") << endl;
             if (doc == md) {
-              section << "|:--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") <<
-                ":--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") << ":-:|";
+              section << "|:--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") << (format == full ? ":-:|" : "") <<
+                ":--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") << (format == full ? ":-:|" : "") << ":-:|";
               if (isJoint())
-                section << ":--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") << ":-:|";
+                section << ":--|" << (format == full ? ":-:|" : "") << ":-:|" << (format == full ? ":-:|" : "") << (format == full ? ":-:|" : "") << ":-:|";
               section << endl;
             }
             switch (format) {
@@ -360,7 +413,7 @@ namespace doc {
               *streams[doc].get() << rows.str() << endl;
             }
           }
-          *streams[doc].get() << endl << (doc == md ? "\\" : "") << (format == full ? "*A - Added; D - Deprecated; R - Removed; E - Experimental" : "*D - Deprecated; E - Experimental");
+          *streams[doc].get() << endl << (doc == md ? "\\" : "") << (format == full ? "*A - Added; D - Deprecated; C - Changed; R - Removed; E - Experimental" : "*D - Deprecated; E - Experimental");
         }
         return true;
       }
@@ -505,11 +558,12 @@ namespace doc {
       const typeMap &getTypes() const override { return CUDA_BLAS_TYPE_NAME_MAP; }
       const versionMap &getFunctionVersions() const override { return CUDA_BLAS_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_BLAS_FUNCTION_VER_MAP; }
+      const hipChangedVersionMap &getHipChangedFunctionVersions() const override { return HIP_BLAS_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_BLAS_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_BLAS_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUBLAS; }
-      const string &getSecondAPI() const { return sROC; }
-      const string &getJointAPI() const { return sHIPandROC; }
+      const string &getSecondAPI() const override { return sROC; }
+      const string &getJointAPI() const override { return sHIPandROC; }
       const string &getFileName(docType format) const override {
         switch (format) {
           case none:
@@ -525,7 +579,7 @@ namespace doc {
       ROCBLAS(const string &outDir): BLAS(outDir) { hasROC = false; isROC = true; }
       virtual ~ROCBLAS() {}
     protected:
-      const string &getAPI() const { return sROC; }
+      const string &getAPI() const override { return sROC; }
       const string &getFileName(docType format) const override {
         switch (format) {
           case none:
@@ -536,6 +590,47 @@ namespace doc {
       }
   };
 
+  class SOLVER : public DOC {
+  public:
+    SOLVER(const string& outDir) : DOC(outDir) { hasROC = true; }
+    virtual ~SOLVER() {}
+  protected:
+    const sectionMap& getSections() const override { return CUDA_SOLVER_API_SECTION_MAP; }
+    const functionMap& getFunctions() const override { return CUDA_SOLVER_FUNCTION_MAP; }
+    const typeMap& getTypes() const override { return CUDA_SOLVER_TYPE_NAME_MAP; }
+    const versionMap& getFunctionVersions() const override { return CUDA_SOLVER_FUNCTION_VER_MAP; }
+    const hipVersionMap& getHipFunctionVersions() const override { return HIP_SOLVER_FUNCTION_VER_MAP; }
+    const versionMap& getTypeVersions() const override { return CUDA_SOLVER_TYPE_NAME_VER_MAP; }
+    const hipVersionMap& getHipTypeVersions() const override { return HIP_SOLVER_TYPE_NAME_VER_MAP; }
+    const string& getName() const override { return sCUSOLVER; }
+    const string& getSecondAPI() const override { return sROC; }
+    const string& getJointAPI() const override { return sHIPandROC; }
+    const string& getFileName(docType format) const override {
+      switch (format) {
+      case none:
+      default: return sEmpty;
+      case md: return roc == joint ? sSOLVER_and_ROC_md : sSOLVER_md;
+      case csv: return roc == joint ? sSOLVER_and_ROC_csv : sSOLVER_csv;
+      }
+    }
+  };
+
+  class ROCSOLVER : public SOLVER {
+  public:
+    ROCSOLVER(const string& outDir) : SOLVER(outDir) { hasROC = false; isROC = true; }
+    virtual ~ROCSOLVER() {}
+  protected:
+    const string& getAPI() const override { return sROC; }
+    const string& getFileName(docType format) const override {
+      switch (format) {
+      case none:
+      default: return sEmpty;
+      case md: return sROCSOLVER_md;
+      case csv: return sROCSOLVER_csv;
+      }
+    }
+  };
+
   class RAND: public DOC {
     public:
       RAND(const string &outDir): DOC(outDir) {}
@@ -572,8 +667,8 @@ namespace doc {
       const versionMap &getTypeVersions() const override { return CUDA_DNN_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_DNN_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUDNN; }
-      const string &getSecondAPI() const { return sMIOPEN; }
-      const string &getJointAPI() const { return sHIPandMIOPEN; }
+      const string &getSecondAPI() const override { return sMIOPEN; }
+      const string &getJointAPI() const override { return sHIPandMIOPEN; }
       const string &getFileName(docType format) const override {
         switch (format) {
           case none:
@@ -589,7 +684,7 @@ namespace doc {
       MIOPEN(const string &outDir): DNN(outDir) { hasROC = false; isROC = true; }
       virtual ~MIOPEN() {}
     protected:
-      const string &getAPI() const { return sMIOPEN; }
+      const string &getAPI() const override { return sMIOPEN; }
       const string &getFileName(docType format) const override {
         switch (format) {
           case none:
@@ -633,11 +728,13 @@ namespace doc {
       const typeMap &getTypes() const override { return CUDA_SPARSE_TYPE_NAME_MAP; }
       const versionMap &getFunctionVersions() const override { return CUDA_SPARSE_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_SPARSE_FUNCTION_VER_MAP; }
+      const hipChangedVersionMap &getHipChangedFunctionVersions() const override { return HIP_SPARSE_FUNCTION_CHANGED_VER_MAP; }
+      const cudaChangedVersionMap &getCudaChangedFunctionVersions() const override { return CUDA_SPARSE_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_SPARSE_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_SPARSE_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCUSPARSE; }
-      const string &getSecondAPI() const { return sROC; }
-      const string &getJointAPI() const { return sHIPandROC; }
+      const string &getSecondAPI() const override { return sROC; }
+      const string &getJointAPI() const override { return sHIPandROC; }
       const string &getFileName(docType format) const override {
         switch (format) {
           case none:
@@ -653,7 +750,7 @@ namespace doc {
     ROCSPARSE(const string &outDir) : SPARSE(outDir) { hasROC = false; isROC = true; }
     virtual ~ROCSPARSE() {}
   protected:
-    const string &getAPI() const { return sROC; }
+    const string &getAPI() const override { return sROC; }
     const string &getFileName(docType format) const override {
       switch (format) {
       case none:
@@ -697,6 +794,7 @@ namespace doc {
       const typeMap &getTypes() const override { return CUDA_RTC_TYPE_NAME_MAP; }
       const versionMap &getFunctionVersions() const override { return CUDA_RTC_FUNCTION_VER_MAP; }
       const hipVersionMap &getHipFunctionVersions() const override { return HIP_RTC_FUNCTION_VER_MAP; }
+      const cudaChangedVersionMap& getCudaChangedFunctionVersions() const override { return CUDA_RTC_FUNCTION_CHANGED_VER_MAP; }
       const versionMap &getTypeVersions() const override { return CUDA_RTC_TYPE_NAME_VER_MAP; }
       const hipVersionMap &getHipTypeVersions() const override { return HIP_RTC_TYPE_NAME_VER_MAP; }
       const string &getName() const override { return sCURTC; }
@@ -772,12 +870,16 @@ namespace doc {
     BLAS blas(sOut);
     docs.addDoc(&blas);
     ROCBLAS rocblas(sOut);
+    SOLVER solver(sOut);
+    docs.addDoc(&solver);
+    ROCSOLVER rocsolver(sOut);
     MIOPEN miopen(sOut);
     ROCSPARSE rocsparse(sOut);
     if (docRoc == separate) {
       docs.addDoc(&rocblas);
       docs.addDoc(&miopen);
       docs.addDoc(&rocsparse);
+      docs.addDoc(&rocsolver);
     }
     RAND rand(sOut);
     docs.addDoc(&rand);
