@@ -142,6 +142,7 @@ const char *apiNames[NUM_API_TYPES] = {
   "cuDNN API",
   "cuFFT API",
   "cuSPARSE API",
+  "cuSOLVER API",
   "CUB API",
   "CAFFE2 API",
   "RTC API"
@@ -157,6 +158,7 @@ const char *apiTypes[NUM_API_TYPES] = {
   "API_FFT",
   "API_CUB",
   "API_SPARSE",
+  "API_SOLVER",
   "API_CAFFE2",
   "API_RTC"
 };
@@ -363,8 +365,9 @@ void Statistics::setActive(const std::string &name) {
 }
 
 bool Statistics::isToRoc(const hipCounter &counter) {
-  return (counter.apiType == API_BLAS || counter.apiType == API_DNN || counter.apiType == API_SPARSE || counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX) &&
-    ((TranslateToRoc && !TranslateToMIOpen && !isRocMiopenOnly(counter)) || TranslateToMIOpen);
+  return (counter.apiType == API_BLAS || counter.apiType == API_DNN || counter.apiType == API_SPARSE || counter.apiType == API_SOLVER ||
+          counter.apiType == API_RUNTIME || counter.apiType == API_COMPLEX) &&
+          ((TranslateToRoc && !TranslateToMIOpen && !isRocMiopenOnly(counter)) || TranslateToMIOpen);
 }
 
 bool Statistics::isHipExperimental(const hipCounter& counter) {
@@ -484,6 +487,7 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDA_120: return "12.0";
     case CUDA_121: return "12.1";
     case CUDA_122: return "12.2";
+    case CUDA_123: return "12.3";
     case CUDNN_10: return "1.0.0";
     case CUDNN_20: return "2.0.0";
     case CUDNN_30: return "3.0.0";
@@ -527,6 +531,11 @@ std::string Statistics::getCudaVersion(const cudaVersions& ver) {
     case CUDNN_890: return "8.9.0";
     case CUDNN_891: return "8.9.1";
     case CUDNN_892: return "8.9.2";
+    case CUDNN_893: return "8.9.3";
+    case CUDNN_894: return "8.9.4";
+    case CUDNN_895: return "8.9.5";
+    case CUDNN_896: return "8.9.6";
+    case CUDNN_897: return "8.9.7";
   }
   return "";
 }
@@ -595,6 +604,9 @@ std::string Statistics::getHipVersion(const hipVersions& ver) {
     case HIP_5050: return "5.5.0";
     case HIP_5060: return "5.6.0";
     case HIP_5070: return "5.7.0";
+    case HIP_6000: return "6.0.0";
+    case HIP_6002: return "6.0.2";
+    case HIP_6010: return "6.1.0";
   }
   return "";
 }
